@@ -1,10 +1,10 @@
-__version__ = "0.1.65"
+__version__ = "0.1.66"
 __git_commiter_name__ = "Arnon Yaari"
 __git_commiter_email__ = "arnony@infinidat.com"
-__git_branch__ = '(Not currently on any branch)'
+__git_branch__ = '(detached from v0.1.66)'
 __git_remote_tracking_branch__ = '(No remote tracking)'
 __git_remote_url__ = '(Not remote tracking)'
-__git_head_hash__ = 'e8dbc3ee13ede83e24ab061ea55ed01755403a17'
-__git_head_subject__ = 'Finished release v0.1.65.'
+__git_head_hash__ = 'ee8cfed11c2533b09e17546c27998f291bcaa0ab'
+__git_head_subject__ = 'Finished release v0.1.66.'
 __git_head_message__ = ''
 __git_dirty_diff__ = ''
\ No newline at end of file
